==> nextcloud-27.1.11.tgz: nextcloud/apps/theming/l10n/eu.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Idatzitako izena luzeegia da",
    "The given web address is too long" : "Idatzitako web helbidea luzeegia da",
    "The given web address is not a valid URL" : "Emandako web helbidea URL baliogabea da",
    "The given legal notice address is too long" : "Emandako lege-ohar helbidea luzeegia da",
    "The given legal notice address is not a valid URL" : "Emandako lege-ohar helbidea ez da baliozko URLa",
    "The given privacy policy address is too long" : "Emandako pribatutasun-gidalerro helbidea luzeegia da",
    "The given privacy policy address is not a valid URL" : "Emandako pribatutasun-gidalerro helbidea ez da baliozko URLa",
    "The given slogan is too long" : "Emandako leloa luzeegia da",
    "The given color is invalid" : "Emandako kolorea ez du balio",
    "Disable-user-theming should be true or false" : "Desgaitu-erabiltzailea-gaiak egia ala faltsua izan behar du",
    "Saved" : "Gordeta",
    "Invalid app given" : "Aplikazio baliogabea eman da",
    "Invalid type for setting \"defaultApp\" given" : "Emandako \"defaultApp\" ezartzeko mota baliogabea",
    "Invalid setting key" : "Ezarpen gako baliogabea",
    "The file was uploaded" : "Fitxategia igo da",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Igotako fitxategiak php.ini fitxategiko upload_max_filesize direktiban zehazturikoa gainditzen du",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Igotako fitxategiak HTML formularioan ezarritako MAX_FILE_SIZE direktiban zehazturikoa gainditzen du",
    "The file was only partially uploaded" : "Fitxategia erdizka igo da",
    "No file was uploaded" : "Ez da fitxategirik igo",
    "Missing a temporary folder" : "Aldi baterako karpeta bat falta da",
    "Could not write file to disk" : "Ezin izan da fitxategia diskoan idatzi",
    "A PHP extension stopped the file upload" : "PHP hedapen batek fitxategiaren igoera gelditu du",
    "No file uploaded" : "Ez da fitxategirik igo",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Gai pertsonalizatua erabiltzen ari zara dagoeneko. Gaiaren aplikazioaren ezarpenak gainidatzi ditzake.",
    "Theming" : "Itxura",
    "Appearance and accessibility" : "Itxura eta irisgarritasuna",
    "PHP Imagick module" : "PHP Imagick modulua",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "\"Imagick\" PHP modulua  ez dago gaituta, nahiz eta gaiak pertsonalizatzeko aplikazioa badagoen. Faviconen sorrerak behar bezala funtziona dezan, modulu hau instalatu eta gaitu behar duzu.",
    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "Instantzia honetako \"imagick\" PHP moduluak ez du SVG onartzen. Bateragarritasuna hobetzeko instalatzea gomendatzen da.",
    "Dark theme with high contrast mode" : "Gai iluna kontraste handiko moduarekin",
    "Enable dark high contrast mode" : "Gaitu kontraste handiko modu iluna",
    "Similar to the high contrast mode, but with dark colours." : "Kontraste handiko moduaren antzekoa, baina kolore ilunekin.",
    "Dark theme" : "Gai iluna",
    "Enable dark theme" : "Gaitu gai iluna",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Gai iluna begiak arintzeko argitasuna eta distira orokorra murriztuz.",
    "System default theme" : "Sistemaren gai lehenetsia",
    "Enable the system default" : "Gaitu sistema lehenetsia",
    "Using the default system appearance." : "Sistemaren itxura lehenetsia erabiltzen.",
    "Dyslexia font" : "Dislexia letra-tipoa",
    "Enable dyslexia font" : "Gaitu dislexia letra-tipoa",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic letra-tipo librea da, dislexiak eragindako ohiko irakurketa akats batzuk leuntzeko diseinatua.",
    "High contrast mode" : "Kontraste handiko modua",
    "Enable high contrast mode" : "Gaitu kontraste handiko modua",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Kontraste handiko modua zuri nabigazioa errazteko. Kalitate bisuala murriztuko da baina argitasuna handiagotu.",
    "Light theme" : "Gai argia",
    "Enable the default light theme" : "Gaitu gai argi lehenetsia",
    "The default light appearance." : "Itxura argi lehenetsia.",
    "Legal notice" : "Ohar legala",
    "Privacy policy" : "Pribatutasun politika",
    "Adjust the Nextcloud theme" : "Doitu Nextcloud gaia",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Gaiak aukera ematen du zure instantziaren eta onartutako bezeroen itxura eta izaera erraz pertsonalizatzeko. Hau erabiltzaile guztientzat ikusgai egongo da.",
    "Upload new logo" : "Igo logo berria",
    "Logo" : "Logoa",
    "Upload new background and login image" : "Igo atzeko planoa eta saioa hasteko irudi berria",
    "Background and login image" : "Atzeko planoa eta saioa hasteko irudia",
    "Advanced options" : "Ezarpen aurreratuak",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instalatu ImageMagick PHP luzapena SVG irudietarako laguntzarekin automatikoki sortzeko igotako logotipo eta kolorean oinarritutako gogoko-ikonoak.",
    "Name" : "Izena",
    "Web link" : "Web esteka",
    "a safe home for all your data" : "zure datu guztientzako toki segurua",
    "Slogan" : "Eslogana",
    "Legal notice link" : "Ohar legalaren esteka",
    "Privacy policy link" : "Pribatutasun politikaren esteka",
    "Header logo" : "Goiburuaren logoa",
    "Upload new header logo" : "Igo goiburuaren logo berria",
    "Favicon" : "Gogoko-ikonoa",
    "Upload new favicon" : "Igo gogoko-ikono berria",
    "User settings" : "Erabiltzaile ezarpenak",
    "Disable user theming" : "Desgaitu erabiltzaile itxura",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Zure instantzia hautatu eta pertsonaliza dezakezun arren, erabiltzaileek atzeko planoa eta koloreak alda ditzakete. Zure pertsonalizazioa aplikatu nahi baduzu, hau aktibatu dezakezu.",
    "Appearance and accessibility settings" : "Itxura eta irisgarritasun ezarpenak",
    "Customization has been disabled by your administrator" : "Zure administratzaileak pertsonalizazioa desgaitu du",
    "Background and color" : "Atzeko planoa eta kolorea",
    "Keyboard shortcuts" : "Teklatuaren lasterbideak",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "Zenbait kasutan, teklatuko lasterbideek erabilerraztasun-tresnekin oztopatu dezakete. Zure tresna behar bezala zentratu ahal izateko, hemen teklatuko lasterbide guztiak desgaitu ditzakezu. Honek aplikazioetan erabilgarri dauden lasterbide guztiak ere desgaituko ditu.",
    "Disable all keyboard shortcuts" : "Desgaitu teklatuaren lasterbide guztiak",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Sarbide unibertsala izatea oso garrantzitsua da guretzat. Web estadandarrak jarraitu eta guztia sagurik gabe erabili ahal izatea bermatzen dugu, pantaila-irakurle moduko software laguntzaileak barne. Helburu bezala jartzen dugu {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 AA mailan betetzea, kontraste altuko modua AAA mailaraino betez.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Arazoren bat aurkitzen baduzu, ez izan zalantzarik eta jakinarazi {issuetracker}gure arazoen jarraipena{linkend} zerbitzuan. Eta parte hartu nahi baduzu, etorri {designteam}gure diseinu taldera{linkend}!",
    "Current selected app: {app}, position {position} of {total}" : "Unean hautatutako aplikazioa: {app}, posizioa {total}(e)tik {position}",
    "Move up" : "Eraman gora",
    "Move down" : "Eraman behera",
    "Custom background" : "Atzeko plano pertsonalizatua",
    "Plain background" : "Atzeko plano arrunta",
    "Default background" : "Atzeko plano lehenetsia",
    "Select a background from your files" : "Hautatu atzeko plano bat zure fitxategietatik",
    "Select background" : "Hautatu atzeko planoa",
    "No background has been selected" : "Ez da atzeko planorik hautatu",
    "Theme selection is enforced" : "Gaiaren hautaketa behartuta dago",
    "Navigation bar settings" : "Nabigazio barraren ezarpenak",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Nabigazio-barran erabilitako aplikazioen ordena konfigura dezakezu. Lehenengo sarrera aplikazio lehenetsia izango da, saioa hasi ondoren edo logoan klik egitean irekita.",
    "The default app can not be changed because it was configured by the administrator." : "Aplikazio lehenetsia ezin da aldatu administratzaile batek konfiguratu duelako.",
    "The app order was changed, to see it in action you have to reload the page." : "Aplikazioen ordena aldatu da, ikusteko orria freskatu behar duzu.",
    "Reset default app order" : "Berrezarri aplikazioen orden lehenetsia",
    "Could not set the app order" : "Ezin izan da aplikazioaren ordena ezarri",
    "Could not reset the app order" : "Ezin izan da aplikazioaren ordena berrezarri",
    "Default app" : "Aplikazio lehenetsia",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "Aplikazio lehenetsia, adibidez, saioa hasi ondoren edo menuko logoan klik egiten denean irekitzen den aplikazioa da.",
    "Use custom default app" : "Erabili aplikazio lehenetsi pertsonalizatua",
    "Global default app" : "Aplikazio lehenetsi globala",
    "Global default apps" : "Aplikazio lehenetsi globalak",
    "Default app priority" : "Aplikazioen prioritate lehenetsia",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Erabiltzaile batentzako aplikazio bat gaituta ez badago, lehentasun txikiagoa duen hurrengo aplikazioa erabiltzen da.",
    "Could not set global default apps" : "Ezin izan dira aplikazio lehenetsi globalak ezarri",
    "Select a custom color" : "Hautatu kolore pertsonalizatu bat",
    "Reset to default" : "Berezarri balio lehenetsira",
    "Upload" : "Igo",
    "Remove background image" : "Kendu atzeko-planoko irudia",
    "Color" : "Kolorea",
    "Background" : "Atzeko planoa",
    "Set a custom background" : "Ezarri atzeko planoko irudi pertsonalizatua",
    "Change color" : "Aldatu kolorea",
    "No background" : "atzeko planorik ez"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.5.tgz: nextcloud/apps/theming/l10n/eu.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Idatzitako izena luzeegia da",
    "The given web address is too long" : "Idatzitako web helbidea luzeegia da",
    "The given web address is not a valid URL" : "Emandako web helbidea URL baliogabea da",
    "The given legal notice address is too long" : "Emandako lege-ohar helbidea luzeegia da",
    "The given legal notice address is not a valid URL" : "Emandako lege-ohar helbidea ez da baliozko URLa",
    "The given privacy policy address is too long" : "Emandako pribatutasun-gidalerro helbidea luzeegia da",
    "The given privacy policy address is not a valid URL" : "Emandako pribatutasun-gidalerro helbidea ez da baliozko URLa",
    "The given slogan is too long" : "Emandako leloa luzeegia da",
    "The given color is invalid" : "Emandako kolorea ez du balio",
    "Disable-user-theming should be true or false" : "Desgaitu-erabiltzailea-gaiak egia ala faltsua izan behar du",
    "Saved" : "Gordeta",
    "Invalid app given" : "Aplikazio baliogabea eman da",
    "Invalid type for setting \"defaultApp\" given" : "Emandako \"defaultApp\" ezartzeko mota baliogabea",
    "Invalid setting key" : "Ezarpen gako baliogabea",
    "The file was uploaded" : "Fitxategia igo da",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Igotako fitxategiak php.ini fitxategiko upload_max_filesize direktiban zehazturikoa gainditzen du",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Igotako fitxategiak HTML formularioan ezarritako MAX_FILE_SIZE direktiban zehazturikoa gainditzen du",
    "The file was only partially uploaded" : "Fitxategia erdizka igo da",
    "No file was uploaded" : "Ez da fitxategirik igo",
    "Missing a temporary folder" : "Aldi baterako karpeta bat falta da",
    "Could not write file to disk" : "Ezin izan da fitxategia diskoan idatzi",
    "A PHP extension stopped the file upload" : "PHP hedapen batek fitxategiaren igoera gelditu du",
    "No file uploaded" : "Ez da fitxategirik igo",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Gai pertsonalizatua erabiltzen ari zara dagoeneko. Gaiaren aplikazioaren ezarpenak gainidatzi ditzake.",
    "Theming" : "Itxura",
    "Appearance and accessibility" : "Itxura eta irisgarritasuna",
    "PHP Imagick module" : "PHP Imagick modulua",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "\"Imagick\" PHP modulua  ez dago gaituta, nahiz eta gaiak pertsonalizatzeko aplikazioa badagoen. Faviconen sorrerak behar bezala funtziona dezan, modulu hau instalatu eta gaitu behar duzu.",
    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "Instantzia honetako \"imagick\" PHP moduluak ez du SVG onartzen. Bateragarritasuna hobetzeko instalatzea gomendatzen da.",
    "Dark theme with high contrast mode" : "Gai iluna kontraste handiko moduarekin",
    "Enable dark high contrast mode" : "Gaitu kontraste handiko modu iluna",
    "Similar to the high contrast mode, but with dark colours." : "Kontraste handiko moduaren antzekoa, baina kolore ilunekin.",
    "Dark theme" : "Gai iluna",
    "Enable dark theme" : "Gaitu gai iluna",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Gai iluna begiak arintzeko argitasuna eta distira orokorra murriztuz.",
    "System default theme" : "Sistemaren gai lehenetsia",
    "Enable the system default" : "Gaitu sistema lehenetsia",
    "Using the default system appearance." : "Sistemaren itxura lehenetsia erabiltzen.",
    "Dyslexia font" : "Dislexia letra-tipoa",
    "Enable dyslexia font" : "Gaitu dislexia letra-tipoa",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic letra-tipo librea da, dislexiak eragindako ohiko irakurketa akats batzuk leuntzeko diseinatua.",
    "High contrast mode" : "Kontraste handiko modua",
    "Enable high contrast mode" : "Gaitu kontraste handiko modua",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Kontraste handiko modua zuri nabigazioa errazteko. Kalitate bisuala murriztuko da baina argitasuna handiagotu.",
    "Light theme" : "Gai argia",
    "Enable the default light theme" : "Gaitu gai argi lehenetsia",
    "The default light appearance." : "Itxura argi lehenetsia.",
    "Legal notice" : "Ohar legala",
    "Privacy policy" : "Pribatutasun politika",
    "Adjust the Nextcloud theme" : "Doitu Nextcloud gaia",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Gaiak aukera ematen du zure instantziaren eta onartutako bezeroen itxura eta izaera erraz pertsonalizatzeko. Hau erabiltzaile guztientzat ikusgai egongo da.",
    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "Atzeko planoko irudi baten ordez atzeko planoko kolore arrunta ezar dezakezu. Atzeko planoko irudi bat erabiltzen baduzu kolore hori aldatzeak aplikazioen menuko ikonoen kolorean eragina izango du.",
    "Background color" : "Atzeko planoaren kolorea",
    "Upload new logo" : "Igo logo berria",
    "Logo" : "Logoa",
    "Upload new background and login image" : "Igo atzeko planoa eta saioa hasteko irudi berria",
    "Background and login image" : "Atzeko planoa eta saioa hasteko irudia",
    "Advanced options" : "Ezarpen aurreratuak",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instalatu ImageMagick PHP luzapena SVG irudietarako laguntzarekin automatikoki sortzeko igotako logotipo eta kolorean oinarritutako gogoko-ikonoak.",
    "Name" : "Izena",
    "Web link" : "Web esteka",
    "a safe home for all your data" : "zure datu guztientzako toki segurua",
    "Slogan" : "Eslogana",
    "Primary color" : "Kolore nagusia",
    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "Kolore nagusia botoi garrantzitsuak bezalako elementuak nabarmentzeko erabiltzen da. Baliteke apur bat doitzea uneko kolore-eskemaren arabera.",
    "Legal notice link" : "Ohar legalaren esteka",
    "Privacy policy link" : "Pribatutasun politikaren esteka",
    "Header logo" : "Goiburuaren logoa",
    "Upload new header logo" : "Igo goiburuaren logo berria",
    "Favicon" : "Gogoko-ikonoa",
    "Upload new favicon" : "Igo gogoko-ikono berria",
    "User settings" : "Erabiltzaile ezarpenak",
    "Disable user theming" : "Desgaitu erabiltzaile itxura",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Zure instantzia hautatu eta pertsonaliza dezakezun arren, erabiltzaileek atzeko planoa eta koloreak alda ditzakete. Zure pertsonalizazioa aplikatu nahi baduzu, hau aktibatu dezakezu.",
    "Appearance and accessibility settings" : "Itxura eta irisgarritasun ezarpenak",
    "Misc accessibility options" : "Irisgarritasun-aukera desberdinak",
    "Enable blur background filter (may increase GPU load)" : "Gaitu atzeko planoa lausotzeko iragazkia (baliteke GPUaren karga handitzea)",
    "Customization has been disabled by your administrator" : "Zure administratzaileak pertsonalizazioa desgaitu du",
    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Ezarri kolore nagusi bat elementu garrantzitsuak nabarmentzeko. Botoi nagusiak bezalako elementuetarako erabiltzen den kolorea apur bat desberdina izan daiteke irisgarritasun-baldintzak betetzeko doitzen baita.",
    "Background and color" : "Atzeko planoa eta kolorea",
    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "Atzeko planoa multzo lehenetsiko irudi bat, kargatutako irudi pertsonalizatua edo kolore arrunta izan daiteke.",
    "Keyboard shortcuts" : "Teklatuaren lasterbideak",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "Zenbait kasutan, teklatuko lasterbideek erabilerraztasun-tresnekin oztopatu dezakete. Zure tresna behar bezala zentratu ahal izateko, hemen teklatuko lasterbide guztiak desgaitu ditzakezu. Honek aplikazioetan erabilgarri dauden lasterbide guztiak ere desgaituko ditu.",
    "Disable all keyboard shortcuts" : "Desgaitu teklatuaren lasterbide guztiak",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Sarbide unibertsala izatea oso garrantzitsua da guretzat. Web estadandarrak jarraitu eta guztia sagurik gabe erabili ahal izatea bermatzen dugu, pantaila-irakurle moduko software laguntzaileak barne. Helburu bezala jartzen dugu {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 AA mailan betetzea, kontraste altuko modua AAA mailaraino betez.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Arazoren bat aurkitzen baduzu, ez izan zalantzarik eta jakinarazi {issuetracker}gure arazoen jarraipena{linkend} zerbitzuan. Eta parte hartu nahi baduzu, etorri {designteam}gure diseinu taldera{linkend}!",
    "Current selected app: {app}, position {position} of {total}" : "Unean hautatutako aplikazioa: {app}, posizioa {total}(e)tik {position}",
    "Move up" : "Eraman gora",
    "Move down" : "Eraman behera",
    "Custom background" : "Atzeko plano pertsonalizatua",
    "Plain background" : "Atzeko plano arrunta",
    "Default background" : "Atzeko plano lehenetsia",
    "Select a background from your files" : "Hautatu atzeko plano bat zure fitxategietatik",
    "Select background" : "Hautatu atzeko planoa",
    "No background has been selected" : "Ez da atzeko planorik hautatu",
    "Theme selection is enforced" : "Gaiaren hautaketa behartuta dago",
    "Navigation bar settings" : "Nabigazio barraren ezarpenak",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Nabigazio-barran erabilitako aplikazioen ordena konfigura dezakezu. Lehenengo sarrera aplikazio lehenetsia izango da, saioa hasi ondoren edo logoan klik egitean irekita.",
    "The default app can not be changed because it was configured by the administrator." : "Aplikazio lehenetsia ezin da aldatu administratzaile batek konfiguratu duelako.",
    "The app order was changed, to see it in action you have to reload the page." : "Aplikazioen ordena aldatu da, ikusteko orria freskatu behar duzu.",
    "Reset default app order" : "Berrezarri aplikazioen orden lehenetsia",
    "Could not set the app order" : "Ezin izan da aplikazioaren ordena ezarri",
    "Could not reset the app order" : "Ezin izan da aplikazioaren ordena berrezarri",
    "Reset primary color" : "Berrezarri kolore nagusia",
    "Could not set primary color" : "Ezin izan da kolore nagusia ezarri",
    "Default app" : "Aplikazio lehenetsia",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "Aplikazio lehenetsia, adibidez, saioa hasi ondoren edo menuko logoan klik egiten denean irekitzen den aplikazioa da.",
    "Use custom default app" : "Erabili aplikazio lehenetsi pertsonalizatua",
    "Global default app" : "Aplikazio lehenetsi globala",
    "Global default apps" : "Aplikazio lehenetsi globalak",
    "Default app priority" : "Aplikazioen prioritate lehenetsia",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Erabiltzaile batentzako aplikazio bat gaituta ez badago, lehentasun txikiagoa duen hurrengo aplikazioa erabiltzen da.",
    "Could not set global default apps" : "Ezin izan dira aplikazio lehenetsi globalak ezarri",
    "Select a custom color" : "Hautatu kolore pertsonalizatu bat",
    "Reset to default" : "Berezarri balio lehenetsira",
    "Upload" : "Igo",
    "Remove background image" : "Kendu atzeko-planoko irudia",
    "Color" : "Kolorea",
    "Background" : "Atzeko planoa",
    "Set a custom background" : "Ezarri atzeko planoko irudi pertsonalizatua",
    "Change color" : "Aldatu kolorea",
    "No background" : "atzeko planorik ez"
},
"nplurals=2; plural=(n != 1);");
